@@ -7,10 +7,11 @@
 ### (we could also use VGAM::qlomax, but this would be slightly slower)
 ###
 ### Copyright (C) 2012-2013 Sebastian Meyer
-### $Revision: 691 $
-### $Date: 2013-12-18 14:09:41 +0100 (Wed, 18. Dec 2013) $
+### $Revision: 2124 $
+### $Date: 2018-05-11 10:10:31 +0200 (Fri, 11. May 2018) $
 ################################################################################
 
-qlomax <- function (p, scale, shape)
+qlomax <- function (p, scale, shape) {
+    .Deprecated("VGAM::qlomax", package = "surveillance")
     scale * ((1-p)^(-1/shape) - 1)
-
+}
