@@ -5,9 +5,9 @@
 ###
 ### Auxiliary functions for operations on spatial data
 ###
-### Copyright (C) 2009-2015 Sebastian Meyer
-### $Revision: 1463 $
-### $Date: 2015-09-07 21:06:12 +0200 (Mon, 07. Sep 2015) $
+### Copyright (C) 2009-2015,2018 Sebastian Meyer
+### $Revision: 2178 $
+### $Date: 2018-07-17 11:04:22 +0200 (Tue, 17. Jul 2018) $
 ################################################################################
 
 
@@ -92,23 +92,14 @@ unionSpatialPolygons <- function (SpP,
 
 
 ### Compute distance from points to a polygonal boundary
-## nncross.ppp() is about 20 times faster than the previous bdist.points()
-## approach [-> distppl()], since it calls C-code [-> distppllmin()]
-## minor drawback: the polygonal boundary needs to be transformed to "psp"
 
-bdist <- function (xy, poly)
+## since spatstat 1.56-0, bdist.points() interfaces C-code via
+## spatstat.utils:::distppllmin, which is faster than nncross.ppp()
+bdist <- function (xy, poly)  # poly is a polygonal "owin"
 {
-    if (nrow(xy) > 0L) {
-        nncross.ppp(
-            X = ppp(x = xy[,1L], y = xy[,2L], check = FALSE),
-            Y = if (is.polygonal(poly)) edges(poly, check = FALSE) else poly,
-            what = "dist"
-        )
-    } else {
-       ## spatstat 1.41-1 returns a 0-row _data.frame_ for the trivial case
-       numeric(0L)
-   }
+    bdist.points(ppp(x = xy[,1L], y = xy[,2L], window = poly, check = FALSE))
 }
+## Example: bdist(coordinates(imdepi$events), as(imdepi$W, "owin"))
 
 
 ### sample n points uniformly on a disc with radius r
@@ -128,7 +119,7 @@ runifdisc <- function (n, r = 1, buffer = 0)
 
 multiplicity.Spatial <- function (x) multiplicity(coordinates(x))
 
-    
+
 ### determines which polygons of a SpatialPolygons object are at the border,
 ### i.e. have coordinates in common with the spatial union of all polygons
 
@@ -176,7 +167,7 @@ layout.labels <- function (obj, labels = TRUE, plot = FALSE)
             obj@data[[labels]]
         } else labels
     }
-    
+
     ## convert labels argument to a list
     labels.args <- if (is.list(labels)) {
         labels
